function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import MediaElement from '../components/MediaElement';
import PropTypes from 'prop-types';
import IIIFParser from '../services/iiif-parser';
import ErrorMessage from '../components/ErrorMessage';

var iiifParser = new IIIFParser();

var MediaElementContainer = function (_Component) {
  _inherits(MediaElementContainer, _Component);

  function MediaElementContainer() {
    var _temp, _this, _ret;

    _classCallCheck(this, MediaElementContainer);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _Component.call.apply(_Component, [this].concat(args))), _this), _this.state = {
      manifestUrl: _this.props.manifestUrl,
      manifest: _this.props.manifest,
      ready: false,
      sources: [],
      error: null
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  MediaElementContainer.prototype.componentDidMount = function componentDidMount() {
    var manifest = this.state.manifest;

    var choiceItems = iiifParser.getChoiceItems(manifest);
    this.prepSources(manifest, choiceItems);
  };

  MediaElementContainer.prototype.getSources = function getSources(choiceItems) {
    var sources = choiceItems.map(function (item) {
      return {
        src: item.id,
        // TODO: make type more generic, possibly use mime-db 
        type: 'application/x-mpegURL'
      };
    });
    return sources;
  };

  MediaElementContainer.prototype.prepSources = function prepSources(manifest, choiceItems) {
    if (choiceItems.length === 0) {
      this.setState({
        error: 'No media choice items found in manifest'
      });
      return;
    }

    var sources = this.getSources(choiceItems);
    this.setState({
      ready: true,
      sources: sources
    });
  };

  MediaElementContainer.prototype.render = function render() {
    var _state = this.state,
        manifest = _state.manifest,
        ready = _state.ready,
        sources = _state.sources,
        error = _state.error;

    var options = {};

    if (ready) {
      return React.createElement(MediaElement, {
        id: 'avln-mediaelement-component',
        mediaType: 'video',
        preload: 'auto',
        controls: true,
        width: manifest.width || 480,
        height: manifest.height || 360,
        poster: '',
        sources: JSON.stringify(sources),
        options: JSON.stringify(options)
      });
    } else if (error) {
      return React.createElement(ErrorMessage, { message: error });
    }
    return null;
  };

  return MediaElementContainer;
}(Component);

MediaElementContainer.propTypes = process.env.NODE_ENV !== "production" ? {
  manifest: PropTypes.object
} : {};

export default MediaElementContainer;